@@ -31,8 +31,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 """
 
+import importlib.util
 import io
 import os
+import sys
 import tempfile
 from unittest.mock import Mock, patch
 import warnings
@@ -458,6 +460,77 @@ class TestSnps(BaseSNPsTestCase):
             self.assertEqual(snps.count, 0)
             self.assertTrue(snps.snps.empty)
 
+    def _make_ancestry_assertions(self, d):
+        self.assertEqual(d["population_code"], "ITU")
+        self.assertEqual(d["population_description"], "Indian Telugu in the UK")
+        self.assertAlmostEqual(d["population_percent"], 0.2992757864426246)
+        self.assertEqual(d["superpopulation_code"], "SAS")
+        self.assertEqual(d["superpopulation_description"], "South Asian Ancestry")
+        self.assertAlmostEqual(d["superpopulation_percent"], 0.827977563875996)
+        self.assertTrue("predicted_population_population" in d["ezancestry_df"].keys())
+        self.assertTrue(
+            "predicted_population_superpopulation" in d["ezancestry_df"].keys()
+        )
+
+    def test_ancestry(self):
+        def pop_modules(modules):
+            d = {}
+            for m in modules:
+                if m in sys.modules:
+                    d[m] = sys.modules.pop(m)
+            return d
+
+        if importlib.util.find_spec("ezancestry") is not None:
+            # test with ezancestry if installed
+            s = SNPs("tests/input/generic.csv")
+            self._make_ancestry_assertions(s.predict_ancestry())
+
+        ezancestry_mods = ["ezancestry", "ezancestry.commands"]
+        popped_mods = pop_modules(ezancestry_mods)
+
+        # mock ezancestry modules
+        for mod in ezancestry_mods:
+            sys.modules[mod] = Mock()
+
+        sys.modules["ezancestry.commands"].predict = Mock(
+            return_value=pd.DataFrame(
+                {
+                    "predicted_population_population": ["ITU"],
+                    "population_description": ["Indian Telugu in the UK"],
+                    "ITU": [0.2992757864426246],
+                    "predicted_population_superpopulation": ["SAS"],
+                    "superpopulation_name": ["South Asian Ancestry"],
+                    "SAS": [0.827977563875996],
+                }
+            )
+        )
+
+        # test with mocked ezancestry
+        s = SNPs("tests/input/generic.csv")
+        self._make_ancestry_assertions(s.predict_ancestry())
+
+        # unload mocked ezancestry modules
+        pop_modules(ezancestry_mods)
+
+        # restore ezancestry modules if ezancestry installed
+        sys.modules.update(popped_mods)
+
+    def test_ancestry_module_not_found_error(self):
+        if importlib.util.find_spec("ezancestry") is None:
+            # test when ezancestry not installed
+            s = SNPs("tests/input/generic.csv")
+            with self.assertRaises(ModuleNotFoundError) as err:
+                _ = s.predict_ancestry()
+
+            self.assertEqual(
+                err.exception.msg,
+                "Ancestry prediction requires the ezancestry package; please install it using pip install ezancestry",
+            )
+
+    def test_ancestry_no_snps(self):
+        for snps in self.empty_snps():
+            self.assertDictEqual(snps.predict_ancestry(), {})
+
 
 class TestSNPsMerge(TestSnps):
     def assert_results(self, results, expected_results):
@@ -884,7 +957,8 @@ class TestDeprecatedMethods(TestSnps):
                 snps = SNPs("tests/input/generic.csv", output_dir=tmpdir)
                 dest = os.path.join(tmpdir, "generic_GRCh37.csv")
                 self.assertEqual(
-                    snps.save_snps(sep=","), dest,
+                    snps.save_snps(sep=","),
+                    dest,
                 )
                 self.run_parsing_tests(dest, "generic")
 
